==> migrate_wizard-1.0.10-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/process/GetFile.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\file\Entity\File;
use Drupal\migrate\MigrateSkipProcessException;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;
use Drupal\Core\File\FileSystemInterface;

/**
 * Get file.
 *
 * @MigrateProcessPlugin(
 *   id = "get_file"
 * )
 */
class GetFile extends ProcessPluginBase {

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $migrationUrlFilesProd;

  /**
   * {@inheritdoc}
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  protected $entityManager;

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {

    $this->config = \Drupal::configFactory()->getEditable('migrate_wizard.settings');
    $this->migrationUrlFilesProd = $this->config->get('migrate_wizard_settings')['migration_url_files_prod'];
    $this->fileSystem = \Drupal::service('file_system');
    $this->entityManager = \Drupal::service('entity_type.manager');

    return $this->createFile($value, $row);
  }

  /**
   * Create file.
   */
  protected function createFile(array $file_data, $row) {

    $file_url = str_replace('public://', $this->migrationUrlFilesProd, $file_data['uri']);

    $directory = str_replace($this->migrationUrlFilesProd, '', $file_url);
    if (basename($file_url) != $directory) {
      $directory = str_replace(basename($file_url), '', $directory);
      $directory = 'public://' . $directory;
    }
    else {
      $directory = 'public://';
    }

    $uri = $directory . basename($file_url);

    $this->fileSystem->prepareDirectory($directory, FileSystemInterface:: CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS);

    if (file_exists($directory . '/' . basename($file_url))) {

      $files = $this->entityManager->getStorage('file')->loadByProperties(['uri' => $uri]);

      $file = reset($files) ?: NULL;
      if ($file == NULL) {
        // Create file with File::create.
        $file = File::create([
          'uri' => $uri,
          'uid' => 1,
          'status' => 1,
        ]);
        $file->save();
      }
    }
    else {

      $url_downloadable = get_headers($file_url);

      // Check the response code.
      if (strpos($url_downloadable[0], '200') !== FALSE) {
        $file = system_retrieve_file($file_url, $directory, TRUE, FileSystemInterface::EXISTS_REPLACE);
      }
      else {
        \Drupal::logger('migrate_wizard')->notice(' File not found: ' . $file_url.' in node: '.$row->getSourceProperty('nid'));
        throw new MigrateSkipProcessException($file_url . ' Error ' . $url_downloadable[0]);
      }

    }

    if ($file instanceof \Drupal\file\FileInterface) {
      if ($file_data["type"] == 'file') {
        $value_file = [
          'target_id' => $file->id(),
          'description' => $file_data['description'],
        ];
      }
      elseif ($file_data["type"] == 'image') {
        $value_file = [
          'target_id' => $file->id(),
          'alt' => $file_data['alt'],
          'title' => $file_data['title'],
          'width' => $file_data['width'],
          'height' => $file_data['height'],
        ];
      }
      $value_file['type'] = $file_data['type'];
      return $value_file;
    }else{
      \Drupal::logger('migrate_wizard')->notice(' File not found: ' . $file_url.' in node: '.$row->getSourceProperty('nid'));
    }
  }

}

==> migrate_wizard-1.0.12-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/process/GetFile.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\file\Entity\File;
use Drupal\migrate\MigrateSkipProcessException;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;
use Drupal\Core\File\FileSystemInterface;

/**
 * Get file.
 *
 * @MigrateProcessPlugin(
 *   id = "get_file"
 * )
 */
class GetFile extends ProcessPluginBase {

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $migrationUrlFilesProd;

  /**
   * {@inheritdoc}
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  protected $entityManager;

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {

    $this->config = \Drupal::configFactory()->getEditable('migrate_wizard.settings');
    $this->migrationUrlFilesProd = $this->config->get('migrate_wizard_settings')['migration_url_files_prod'];
    $this->fileSystem = \Drupal::service('file_system');
    $this->entityManager = \Drupal::service('entity_type.manager');

    return $this->createFile($value, $row);
  }

  /**
   * Create file.
   */
  protected function createFile(array $file_data, $row) {

    $file_url = str_replace('public://', $this->migrationUrlFilesProd, $file_data['uri']);

    $directory = str_replace($this->migrationUrlFilesProd, '', $file_url);
    if (basename($file_url) != $directory) {
      $directory = str_replace(basename($file_url), '', $directory);
      $directory = 'public://' . $directory;
    }
    else {
      $directory = 'public://';
    }

    $uri = $directory . basename($file_url);

    $this->fileSystem->prepareDirectory($directory, FileSystemInterface:: CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS);

    if (file_exists($directory . '/' . basename($file_url))) {

      $files = $this->entityManager->getStorage('file')->loadByProperties(['uri' => $uri]);

      $file = reset($files) ?: NULL;
      if ($file == NULL) {
        // Create file with File::create.
        $file = File::create([
          'uri' => $uri,
          'uid' => 1,
          'status' => 1,
        ]);
        $file->save();
      }
    }
    else {

//      $url_downloadable = get_headers($file_url);

      // Check the response code.
      if (true) {
        $file = system_retrieve_file($file_url, $directory, TRUE, FileSystemInterface::EXISTS_REPLACE);
      }
      else {
        \Drupal::logger('migrate_wizard')->notice(' File not found: ' . $file_url.' in node: '.$row->getSourceProperty('nid'));
        throw new MigrateSkipProcessException($file_url . ' Error ' . $url_downloadable[0]);
      }

    }

    if ($file instanceof \Drupal\file\FileInterface) {
      if ($file_data["type"] == 'file') {
        $value_file = [
          'target_id' => $file->id(),
          'description' => $file_data['description'],
        ];
      }
      elseif ($file_data["type"] == 'image') {
        $value_file = [
          'target_id' => $file->id(),
          'alt' => $file_data['alt'],
          'title' => $file_data['title'],
          'width' => $file_data['width'],
          'height' => $file_data['height'],
        ];
      }
      $value_file['type'] = $file_data['type'];
      return $value_file;
    }else{
      \Drupal::logger('migrate_wizard')->notice(' File not found: ' . $file_url.' in node: '.$row->getSourceProperty('nid'));
    }
  }

}
